# Algorithms

- [algorithms.modern.nsga2_imkt](algorithms/algorithms.modern.nsga2_imkt.md)
- [algorithms.modern.nsga2_imkt_lstm](algorithms/algorithms.modern.nsga2_imkt_lstm.md)
- [algorithms.modern.nsga2_imkt_clstm](algorithms/algorithms.modern.nsga2_imkt_clstm.md)
